@@ -1,6 +1,6 @@
 {-# LANGUAGE TypeOperators #-}
 {-# LANGUAGE DataKinds #-}
-module Test.MockCat.Cons ((:>)(..)) where
+module Test.MockCat.Cons ((:>)(..), Head(..)) where
 
 data a :> b = a :> b
 
@@ -11,3 +11,9 @@ instance (Eq a, Eq b) => Eq (a :> b) where
   (a :> b) == (a2 :> b2) = (a == a2) && (b == b2)
 
 infixr 8 :>
+
+-- | Marker type for constant value mock functions.
+--   Used to distinguish constant values (Head :> Param r) from
+--   regular mock functions (Param a :> rest).
+data Head = Head
+  deriving (Eq, Show)
