@@ -18,16 +18,21 @@ module Test.MockCat.TH
     makeAutoLiftMock,
     makePartialMock,
     makeAutoLiftPartialMock,
+    deriveMockInstances,
+    deriveNoopInstance,
   )
 where
 
-import Control.Monad (unless, when)
+import Control.Monad (replicateM, unless, when)
+import Control.Monad.Trans (lift)
 import Data.List (elemIndex, nub)
 import Data.Maybe (catMaybes)
 import qualified Data.Map.Strict as Map
 
 import Language.Haskell.TH
-  ( Cxt,
+  ( Clause (..),
+    Body (..),
+    Cxt,
     Dec (..),
     Exp (..),
     Extension (..),
@@ -44,6 +49,7 @@ import Language.Haskell.TH
     Type (..),
     isExtEnabled,
     mkName,
+    newName,
     pprint,
     reify,
   )
@@ -73,7 +79,8 @@ import Test.MockCat.TH.ContextBuilder
   )
 import Test.MockCat.TH.TypeUtils
   ( splitApps,
-    substituteType
+    substituteType,
+    getReturnType
   )
 import Test.MockCat.TH.FunctionBuilder
   ( createFnName,
@@ -181,7 +188,7 @@ makeMock t = doMakeMock t Total options
 --
 --  - MockT instance of the given typeclass
 --  - A stub function corresponding to a function of the original class type.
--- The name of stub function is the name of the original function with a "_" appended.
+-- THE name of stub function is the name of the original function with a "_" appended.
 --
 --  This function automatically wraps the return value in a monad (Implicit Monadic Return).
 --
@@ -605,4 +612,93 @@ mockDec _ _ _ _ dec = fail $ "unsupport dec: " <> pprint dec
 
 
 verifyExtension :: Extension -> Q ()
-verifyExtension e = isExtEnabled e >>= flip unless (fail $ "Language extensions `" ++ show e ++ "` is required.")
\ No newline at end of file
+verifyExtension e = isExtEnabled e >>= flip unless (fail $ "Language extensions `" ++ show e ++ "` is required.")
+
+deriveMockInstances :: Q Type -> Q [Dec]
+deriveMockInstances qType = do
+  ty <- qType
+  let className = getClassName ty
+  classMetadata <- loadClassMetadata className
+  monadVarName <- selectMonadVarName classMetadata
+  let classParamNames = filter (className /=) (getClassNames ty)
+      newTypeVars = drop (length classParamNames) (cmTypeVars classMetadata)
+  let sigDecs = [dec | dec@(SigD _ _) <- cmDecs classMetadata]
+  
+  let isSupportedDec (SigD _ _) = True
+      isSupportedDec (PragmaD _) = True
+      isSupportedDec _ = False
+  let unsupportedDecs = filter (not . isSupportedDec) (cmDecs classMetadata)
+  
+  instanceBodyDecsResult <- 
+    case unsupportedDecs of
+      (x:_) -> pure $ Left $ "deriveMockInstances: Unsupported declaration in class: " <> pprint x <> 
+                        ". This error is reported at the usage site, but the cause is the macro definition for `" <> show className <> "`."
+      [] -> sequence <$> mapM (createLiftInstanceFnDec monadVarName) sigDecs
+
+  case instanceBodyDecsResult of
+    Right decs -> do
+      instanceHead <- createInstanceType ty monadVarName newTypeVars
+      let instanceConstraint = foldl AppT ty (map (VarT . getTypeVarName) newTypeVars)
+      instanceDec <- instanceD
+        (pure (instanceConstraint : cmContext classMetadata))
+        (pure instanceHead)
+        (map pure decs)
+      pure [instanceDec]
+    Left err -> fail err
+
+createLiftInstanceFnDec :: Name -> Dec -> Q (Either String Dec)
+createLiftInstanceFnDec _ (SigD fnName ty) = do
+  let n = countArgs ty
+  argNames <- replicateM n (newName "a")
+  let params = map VarP argNames
+      args = map VarE argNames
+      body = NormalB $ AppE (VarE 'lift) (foldl AppE (VarE fnName) args)
+  pure $ Right $ FunD fnName [Clause params body []]
+createLiftInstanceFnDec _ dec = pure $ Left $ 
+  "deriveMockInstances: Unsupported declaration in class: " <> pprint dec <> 
+  ". Currently only standard method signatures are supported for automatic derivation."
+
+deriveNoopInstance :: Q Type -> Q [Dec]
+deriveNoopInstance qType = do
+  ty <- qType
+  let className = getClassName ty
+  classMetadata <- loadClassMetadata className
+  monadVarName <- selectMonadVarName classMetadata
+  let classParamNames = filter (className /=) (getClassNames ty)
+      newTypeVars = drop (length classParamNames) (cmTypeVars classMetadata)
+  let sigDecs = [dec | dec@(SigD _ _) <- cmDecs classMetadata]
+  instanceBodyDecs <- mapM createNoopInstanceFnDec sigDecs
+  case sequence instanceBodyDecs of
+    Right decs -> do
+      instanceHead <- createInstanceType ty monadVarName newTypeVars
+      instanceDec <- instanceD
+        (pure (cmContext classMetadata))
+        (pure instanceHead)
+        (map pure decs)
+      pure [instanceDec]
+    Left err -> fail err
+
+createNoopInstanceFnDec :: Dec -> Q (Either String Dec)
+createNoopInstanceFnDec (SigD fnName ty) = do
+  let n = countArgs ty
+  let returnType = getReturnType ty
+  case returnType of
+    AppT _ (TupleT 0) -> do
+      let params = replicate n WildP
+          body = NormalB $ AppE (VarE 'pure) (ConE '())
+      pure $ Right $ FunD fnName [Clause params body []]
+    _ -> pure $ Left $ 
+      "deriveNoopInstance: Function `" <> nameBase fnName <> "` does not return `m ()` (actual return type: " <> pprint returnType <> "). " <> 
+      "`deriveNoopInstance` only supports functions that return `m ()`. " <> 
+      "Please implement this instance manually or exclude this function from the derivation target."
+createNoopInstanceFnDec dec = pure $ Left $ 
+  "deriveNoopInstance: Unsupported declaration in class: " <> pprint dec <> 
+  ". Currently only standard method signatures are supported for automatic derivation."
+
+countArgs :: Type -> Int
+countArgs (AppT (AppT ArrowT _) t) = 1 + countArgs t
+countArgs (ForallT _ _ t) = countArgs t
+countArgs (SigT t _) = countArgs t
+countArgs (ParensT t) = countArgs t
+countArgs _ = 0
+
