@@ -1,4 +1,5 @@
 {-# LANGUAGE ScopedTypeVariables #-}
+{-# OPTIONS_GHC -fno-hpc #-}
 module Property.ScriptProps
   ( prop_script_count_matches
   ) where
@@ -11,6 +12,7 @@ import Property.Generators
 -- | Property: executing a generated script produces exactly that many recorded calls.
 prop_script_count_matches :: Property
 prop_script_count_matches = forAll scriptGen $ \scr@(Script xs) -> monadicIO $ do
+  run resetMockHistory
   f <- run $ buildUnaryMock scr
   run $ runScript f scr
   run $ f `shouldBeCalled` times (length xs)
