@@ -1,5 +1,6 @@
 import Test.Hspec (hspec, describe, it)
 import Test.MockCat.MockSpec as Mock
+import Test.MockCat.DeriveSpec as Derive
 import Test.MockCat.ConsSpec as Cons
 import Test.MockCat.ParamSpec as Param
 import Test.MockCat.AssociationListSpec as AssociationList
@@ -26,7 +27,6 @@ import Test.MockCat.WithMockErrorDiffSpec as WithMockErrorDiff
 import Test.MockCat.THCompareSpec as THCompare
 import ReadmeVerifySpec as ReadmeVerify
 import qualified Test.MockCat.HPCFallbackSpec as HPCFallback
-import qualified Test.MockCat.DeferredTypeErrorsSpec as DeferredTypeErrors
 import qualified Test.MockCat.MultipleMocksSpec as MultipleMocks
 import Test.MockCat.UnsafeCheck ()
 import Test.QuickCheck (property)
@@ -44,6 +44,7 @@ main :: IO ()
 main = hspec $ do
     Cons.spec
     Param.spec
+    Derive.spec
     Mock.spec
     AssociationList.spec
     Example.spec
@@ -68,7 +69,6 @@ main = hspec $ do
     WithMockErrorDiff.spec
     ReadmeVerify.spec
     HPCFallback.spec
-    DeferredTypeErrors.spec
     MultipleMocks.spec
     describe "Property Concurrency" $ do
       it "total apply count is preserved across threads" $ property ConcurrencyProp.prop_concurrent_total_apply_count
