@@ -39,7 +39,9 @@ module Test.MockCat.SharedSpecDefs
     TestClass(..),
     Teletype(..),
     UserInput(..),
-    UserInputGetter(..)
+    UserInputGetter(..),
+    Post(..),
+    UserDefinedClass(..)
   )
 where
 
@@ -154,4 +156,10 @@ class Monad m => FinderNoImplicit a b m | a -> b, b -> a where
 findValueNI :: FinderNoImplicit a b m => m [b]
 findValueNI = do
   ids <- findIdsNI
-  mapM findByIdNI ids
\ No newline at end of file
+  mapM findByIdNI ids
+
+data Post = Post { postId :: Int, title :: String }
+  deriving (Eq, Show)
+
+class Monad m => UserDefinedClass m where
+  processPost :: Post -> m Bool
\ No newline at end of file
