@@ -31,8 +31,7 @@ import Data.Text (Text, pack, isInfixOf)
 import Control.Exception (ErrorCall(..), displayException)
 import Control.Monad.IO.Class (MonadIO(..))
 import Control.Monad.Reader (MonadReader, ask)
-import Control.Monad.State (MonadState(..), StateT, evalStateT)
-import Control.Monad.Trans.Class (lift)
+import Control.Monad.State (StateT, evalStateT)
 import Test.MockCat.SharedSpecDefs
 import qualified Data.List as List
 import Control.Concurrent.Async (async, wait)
@@ -49,11 +48,6 @@ missingCall name err =
 
 -- Orphan Instances needed for testing
 
-instance MonadState s m => MonadState s (MockT m) where
-  get = lift get
-  put = lift . put
-  state f = lift (state f)
-
 -- Programs under test
 
 data Environment = Environment { inputPath :: String, outputPath :: String }
